import logging
import re


def __dow(day, month, year):
    week = [
        "Domingo",
        "Lunes",
        "Martes",
        "Miércoles",
        "Jueves",
        "Viernes",
        "Sábado",
        "Domingo",
    ]

    year = int(year)
    month = int(month)
    day = int(day)

    if month % 2 == 0:
        if 1 <= month < 7:
            if month == 2:
                if day < 1 or day > 28:
                    return 0
            else:
                if day < 1 or day > 30:
                    return 0
        if 7 < month <= 12:
            if day < 1 or day > 31:
                return 0
    else:
        if 1 <= month < 7:
            if day < 1 or day > 31:
                return 0
        if month == 7:
            if day < 1 or day > 31:
                return 0
        if 7 < month <= 12:
            if day < 1 or day > 30:
                return 0

    t = [0, 3, 2, 5, 0, 3, 5, 1, 4, 6, 2, 4]
    if month < 3:
        year -= 1

    return week[
        round((year + year / 4 - year / 100 + year / 400 + t[month - 1] + day) % 7)
    ]


def date(text, type, debug):
    """
    Method for format dates or eliminate it.

    :param text: The text to be preprocessed
    :type: str

    :param type: Type of date (eliminate or format)
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    months = [
        "Enero",
        "Febrero",
        "Marzo",
        "Abril",
        "Mayo",
        "Junio",
        "Julio",
        "Agosto",
        "Septiembre",
        "Octubre",
        "Noviembre",
        "Diciembre",
    ]

    date_format = ""
    date_format_ = ""
    day = ""
    month = ""

    if re.findall(r"((\d{1,2}/\d{1,2}/\d{4})|(\d{1,2}\-\d{1,2}\-\d{4}))", text):
        date_format = re.search(
            r"((\d{1,2}/\d{1,2}/\d{4})|(\d{1,2}\-\d{1,2}\-\d{4}))", text
        )
        date_format = date_format.group(1)
        date_format_ = date_format.replace("-", "/")
        dmy = date_format_.split("/")

        try:
            day = __dow(dmy[0], dmy[1], dmy[2])
            if day == 0:
                raise IndexError

            month = months[int(dmy[1]) - 1]

            if type == "complete":
                text = text.replace(
                    date_format, f"{day} {dmy[0]} de {month} de {dmy[2]}"
                )
            if type == "eliminate":
                text = text.replace(date_format, "")
            if type == "month":
                text = text.replace(date_format, f"{month}")
            if type == "month_year":
                text = text.replace(date_format, f"{month} de {dmy[2]}")

            if type == "eliminate":
                logging.debug("-- Date eliminated!")
            else:
                logging.debug("-- Date formated!")
        except IndexError:
            print(f"ERROR: Date out of range: {dmy}")

    else:
        logging.debug("-- the text doesnt has any valid date format!")

    return text


if __name__ == "__main__":
    date()



import logging
import re

CLEANHTML = re.compile("<.*?>|&([a-z0-9]+|#[0-9]{1,6}|#x[0-9a-f]{1,6});")
CLEANURL = re.compile(r"http\S+")
CLEANMENTIONS = re.compile("@([a-zA-Z0-9_]{1,50})")
CLEANHASHTAGS = re.compile("#([a-zA-Z0-9_]{1,50})")
CLEANEMAIL = re.compile(r"[a-z0-9\.\-+_]+@[a-z0-9\.\-+_]+\.[a-z]+")


def media(text, format, debug) -> str:
    """
    Method for delete social media tags in text.

    :param text: The text to be preprocessed.
    :type: str

    :param format: Type of social media ([multi | html | url | mention | hashtag | email]:[replace | delete]).
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    if "multi" in format:
        if "delete" in format:
            text = re.sub(CLEANHTML, "", text)
            text = re.sub(CLEANURL, "", text)
            text = re.sub(CLEANEMAIL, "", text)
            text = re.sub(CLEANHASHTAGS, "", text)
            text = re.sub(CLEANMENTIONS, "", text)
        else:
            text = re.sub(CLEANHTML, "", text)  # Waiting for issues..
            text = re.sub(CLEANURL, "<<URL>>", text)
            text = re.sub(CLEANEMAIL, "<<EMAIL>>", text)
            text = re.sub(CLEANHASHTAGS, "<<HASHTAG>>", text)
            text = re.sub(CLEANMENTIONS, "<<MENTION>>", text)
    if "html" in format:
        if "delete" in format:
            text = re.sub(CLEANHTML, "", text)
        else:
            text = re.sub(CLEANHTML, " <<HTMLTAG>> ", text)
    if "hashtag" in format:
        if "delete" in format:
            text = re.sub(CLEANHASHTAGS, "", text)
        else:
            text = re.sub(CLEANHASHTAGS, "<<HASHTAG>>", text)
    if "url" in format:
        if "delete" in format:
            text = re.sub(CLEANURL, "", text)
        else:
            text = re.sub(CLEANURL, "<<URL>>", text)
    if "mention" in format:
        if "delete" in format:
            text = re.sub(CLEANMENTIONS, "", text)
        else:
            text = re.sub(CLEANMENTIONS, "<<MENTION>>", text)
    if "email" in format:
        if "delete" in format:
            text = re.sub(CLEANEMAIL, "", text)
        else:
            text = re.sub(CLEANEMAIL, "<<EMAIL>>", text)

    return text


if __name__ == "__main__":
    media()



import logging
import spacy
import re

CLEANDNI = re.compile(
    r"[0-9]{8}[a-z] | [0-9]{8}-[a-z] | [0-9]{2}.[0-9]{3}.[0-9]{3}-[a-z] | [0-9]{2}.[0-9]{3}.[0-9]{3}[a-z] | [a-z][0-9]{7}[a-z] | [a-z][0-9]{7}-[a-z]"
)
CLEANTLFN = re.compile(
    r"((\s\d{9})|(\s\d{3} \d{3} \d{3})|(\s\d{3}-\d{3}-\d{3})|(\s\d{1,3} \d{3}-\d{3}-\d{3})|(\s\+\d{1,3} \d{3} \d{3} \d{3}))"
)
CLEANIP = re.compile(r"(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})")

spanish_nlp = spacy.load("es_core_news_sm")


def privacy(text, format, debug) -> str:
    """
    Method for clean personal data from text.

    :param text: The text to be preprocessed.
    :type: str

    :param format: Type of privacy ([multi | dni | tlfn | name | ip]:[replace | delete]).
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )
    text = text.replace(",", " ,")  # Spacy conflicts with comma

    if "multi" in format:
        if "delete" in format:
            spacy_parser = spanish_nlp(text)
            for entity in spacy_parser.ents:
                if entity.label_ == "PER":
                    text = spacy_parser.text.replace(entity.text, "")
            text = re.sub(CLEANDNI, "", text)
            text = re.sub(CLEANTLFN, "", text)
            text = re.sub(CLEANIP, "", text)
        else:

            text = re.sub(CLEANDNI, " <<DNI>> ", text)
            text = re.sub(CLEANTLFN, " <<TLFN>> ", text)
            text = re.sub(CLEANIP, " <<IP>> ", text)
            spacy_parser = spanish_nlp(text)
            for entity in spacy_parser.ents:
                if entity.label_ == "PER":
                    text = spacy_parser.text.replace(entity.text, "<<PERSON>>")

    if "dni" in format:
        if "delete" in format:
            text = re.sub(CLEANDNI, "", text)
        else:
            text = re.sub(CLEANDNI, " <<DNI>> ", text)
    if "tlfn" in format:
        if "delete" in format:
            text = re.sub(CLEANTLFN, "", text)
        else:
            text = re.sub(CLEANTLFN, " <<TLFN>> ", text)
    if "ip" in format:
        if "delete" in format:
            text = re.sub(CLEANIP, "", text)
        else:
            text = re.sub(CLEANIP, " <<IP>> ", text)
    if "name" in format:
        if "delete" in format:
            spacy_parser = spanish_nlp(text)
            for entity in spacy_parser.ents:
                if entity.label_ == "PER":
                    text = spacy_parser.text.replace(entity.text, "")
        else:
            spacy_parser = spanish_nlp(text)
            for entity in spacy_parser.ents:
                if entity.label_ == "PER":
                    text = spacy_parser.text.replace(entity.text, "<<PERSON>>")

    return text


if __name__ == "__main__":
    privacy()



from collections import Counter
from pathlib import Path
import re


def words(text):
    return re.findall(r"\w+", text.lower())


path = Path(__file__).parent.parent.parent / "./_external/corpus.txt"
WORDS = Counter(words(open(path).read()))


def PROB(word, N=sum(WORDS.values())):
    "Probability of `word`."
    return WORDS[word] / N


def correction(word):
    "Most probable spelling correction for word."
    return max(candidates(word), key=PROB)


def candidates(word):
    "Generate possible spelling corrections for word."
    return (
        known([word]) or known(first_edit(word)) or known(second_edit(word)) or [word]
    )


def known(words):
    "The subset of `words` that appear in the dictionary of WORDS."
    return set(w for w in words if w in WORDS)


def first_edit(word):
    "All edits that are one edit away from `word`."
    letters = "abcdefghijklmnopqrstuvwxyz"
    splits = [(word[:i], word[i:]) for i in range(len(word) + 1)]
    deletes = [L + R[1:] for L, R in splits if R]
    transposes = [L + R[1] + R[0] + R[2:] for L, R in splits if len(R) > 1]
    replaces = [L + c + R[1:] for L, R in splits if R for c in letters]
    inserts = [L + c + R for L, R in splits for c in letters]
    return set(deletes + transposes + replaces + inserts)


def second_edit(word):
    "All edits that are two edits away from `word`."
    return (e2 for e1 in first_edit(word) for e2 in first_edit(e1))



import pandas as pd
import logging
from pathlib import Path
import csv

path = Path(__file__).parent / "../_external/stopwords.csv"
stopwords = pd.read_csv(path)["stopwords"].tolist()


def stopwords_es(text, debug):
    """
    Method for eliminate text punctuation.

    :param text: The text to be preprocessed
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    text = text.split()
    text = " ".join(word for word in text if word not in stopwords)
    logging.debug("-- Stopwords cleanned!")

    return text


if __name__ == "__main__":
    stopwords_es()



from .core.punctuation import punctuation_es
from .core.numbers import numbers_cleanner
from .core.autocorrect import autocorrect
from .core.lowercasing import lowercasing
from .core.stopwords import stopwords_es
from .core.tokenizer import tokenizer
from sqlalchemy import create_engine
from .core.accents import accents
from .core.privacy import privacy
from distutils.log import error
from .core.media import media
from .core.date import date

import pandas as pd
import sqlalchemy
import logging
import os


class Preprocessing:
    """Preln main class. Preprocess a given spanish text.
    Use pipeline(), pipelineFile() or databasePipeline() to use the package.
    """

    def __init__(
        self,
        date=False,
        date_format=None,
        accents=False,
        lowercasing=True,
        privacy=False,
        privacy_format="multi:delete",
        correction=False,
        media=False,
        media_format="multi:delete",
        numbers=True,
        punctuation=True,
        stopwords=True,
        tokenizer=True,
        debug=False,
    ):
        """Preprocessing class constructor.
        Initialize and custom pre-processing pipeline.

        Args:
          date (bool, optional): Date formatter or delete date from text. Defaults to False.
          date_format (string, optional): Type of date format [complete, month, month_year, eliminate]. Defaults to None.
          accents (bool, optional): Accents cleanner from [Árbol] to [Arbol]. Defaults to False.
          lowercasing (bool, optional): Lowercase text. Defaults to True.
          numbers (bool, optional): Delete numbers pattern. Defaults to True.
          punctuation (bool, optional): Delete text punctuation [Spanish punctuation included]. Defaults to True.
          stopwords (bool, optional): Delete and clean dont wanted words in text. Defaults to True.
          tokenizer (bool, optional): Transform string to list (to summ up). Defaults to True.
          debug (bool, optional): Displays the code execution log by console. Defaults to False.
        """
        self.__date = date
        self.__date_format = date_format
        self.__accents = accents
        self.__lowercasing = lowercasing
        self.__privacy = privacy
        self.__privacy_format = privacy_format
        self.__correction = correction
        self.__media = media
        self.__media_format = media_format
        self.__numbers = numbers
        self.__debug = debug
        self.__punctuation = punctuation
        self.__stopwords = stopwords
        self.__tokenizer = tokenizer

    def pipeline(self, text) -> str:
        """Pre-processes a given text by
        applying the different pre-processing methods.

        Args:
          text (str): Text to be pre-processed.

        Returns:
          str: Pre-processed text.
        """
        if self.__debug:
            logging.basicConfig(
                level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
            )
        logging.debug("> Starting preprocessing pipeline...")

        # Preprocessing pipeline creation
        try:
            if self.__date:
                text = date(text=text, type=self.__date_format, debug=self.__debug)
            if self.__accents:
                text = accents(text=text, debug=self.__debug)
            if self.__lowercasing:
                text = lowercasing(text=text, debug=self.__debug)
            if self.__privacy:
                text = privacy(
                    text=text, format=self.__privacy_format, debug=self.__debug
                )
            if self.__correction:
                text = autocorrect(text=text, debug=self.__debug)
            if self.__media:
                text = media(text=text, format=self.__media_format, debug=self.__debug)
            if self.__numbers:
                text = numbers_cleanner(text=text, debug=self.__debug)
            if self.__punctuation:
                text = punctuation_es(text=text, debug=self.__debug)
            if self.__stopwords:
                text = stopwords_es(text=text, debug=self.__debug)
            if self.__tokenizer:
                text = tokenizer(text=text, debug=self.__debug)

            logging.debug("Preprocessing pipeline completed! <")
            logging.debug("")

            return text

        except TypeError:
            error("ERROR: Given text type must be a unique string!")
            logging.debug("Preprocessing pipeline failed! <")
            logging.debug("")

    def filePipeline(self, filePath, key) -> list:
        """Pre-processes a given file by
        applying the different preprocessing methods.

        Args:
          filePath (str): The file to be pre-processed.
          key (str): Dataframe key(column).

        Returns:
          list: A list of the contents of the pre-processed file.
        """
        if self.__debug:
            logging.basicConfig(
                level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
            )
        logging.debug("> Starting preprocessing pipeline...")

        try:
            split_path = os.path.splitext(filePath)
            ext = split_path[1].replace(".", "")

            if ext == "csv":
                df = pd.read_csv(filePath)
            if ext == "xml":
                df = pd.read_xml(filePath)
            if ext == "excel":
                df = pd.read_excel(filePath)
            if ext == "json":
                df = pd.read_json(filePath)

            texts = df[key].values.tolist()
            array = []

            for text in texts:
                text = self.pipeline(text)
                array.append(text)

            logging.debug("Preprocessing pipeline completed! <")
            logging.debug("")

            return array

        except UnboundLocalError:
            error(
                "ERROR: Take care with file path extension, must be one of these: .csv .xml .json .xlsx!"
            )
            logging.debug("Preprocessing pipeline failed! <")
            logging.debug("")
        except FileNotFoundError:
            error("ERROR: File path does not exists, check function arguments!")
            logging.debug("Pre-processed data file creation failed! <")
            logging.debug("")
        except TypeError:
            error("ERROR: Given file path type must be a unique string!")
            logging.debug("Preprocessing pipeline failed! <")
            logging.debug("")
        except KeyError:
            error(
                "ERROR: Given dataframe key(column) must be a unique string and must exist in the dataframe!"
            )
            logging.debug("Preprocessing pipeline failed! <")
            logging.debug("")

    def databasePipeline(
        self, hostname, username, password, dbname, port, table, key
    ) -> list:
        """Pre-processes a SQL database by
        applying the different preprocessing methods.

        Args:
          hostname (str): DB host name.
          username (str): DB user name.
          password (str): DB user password.
          dbname (str): DB name.
          port (str): DB port.
          table (str): Table created in the DB.
          key (str): Table key(column).

        Returns:
          list: A list of the contents of the pre-processed file.
        """
        if self.__debug:
            logging.basicConfig(
                level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
            )
        logging.debug("> Starting preprocessing pipeline...")

        try:
            connect_info = f"mysql+pymysql://{username}:{password}@{hostname}:{port}/{dbname}?charset=utf8"
            engine = create_engine(connect_info, pool_pre_ping=True)

            # SQL Command and execution
            sql_cmd = f"SELECT * FROM {table}"
            df = pd.read_sql(sql=sql_cmd, con=engine)

            texts = df[key].values.tolist()
            array = []

            for text in texts:
                text = self.pipeline(text)
                array.append(text)

            logging.debug("Preprocessing pipeline completed! <")
            logging.debug("")

            return array

        except sqlalchemy.exc.OperationalError:
            error("ERROR: Take care with your database info, check function arguments!")
            logging.debug("Preprocessing pipeline failed! <")
            logging.debug("")
        except sqlalchemy.exc.ProgrammingError:
            error("ERROR: There is a problem with your table name, it does nbt exists!")
            logging.debug("Pre-processed data file creation failed! <")
            logging.debug("")
        except KeyError:
            error(
                "ERROR: Given dataframe key(column) must be a unique string and must exist in the dataframe!"
            )
            logging.debug("Preprocessing pipeline failed! <")
            logging.debug("")

    def write(
        self, textList, originalFilePath=None, outputFilePath="./preprossedText.csv"
    ) -> None:
        """Convert pre-processed text list to a csv file
        or override original file adding pre-processed text.

        Args:
          textList (list): list with pre-processed text.
          originalFilePath (str, optional): Original file, containing text without pre-processed text. Defaults to None.
          outputFilePath (str, optional): Output file. Defaults to './preprossedText.csv'.

        Raises:
          Exception: handle if textList is not a list.
        """
        if self.__debug:
            logging.basicConfig(
                level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
            )
        logging.debug("> Creating new file...")

        try:
            if type(textList) != list:
                raise Exception
            try:
                if originalFilePath == None:
                    df = pd.DataFrame()
                    df["text"] = textList
                    df.to_csv(outputFilePath, index=False)
                else:
                    split_path = os.path.splitext(originalFilePath)
                    ext = split_path[1].replace(".", "")

                    if ext == "csv":
                        df = pd.read_csv(originalFilePath)
                    if ext == "xml":
                        df = pd.read_xml(originalFilePath)
                    if ext == "excel":
                        df = pd.read_excel(originalFilePath)
                    if ext == "json":
                        df = pd.read_json(originalFilePath)

                    df["preprocessed_text"] = textList
                    df.to_csv(outputFilePath, index=False)

            except UnboundLocalError:
                error(
                    "ERROR: Take care with file path extension, must be one of these: .csv .xml .json .xlsx!"
                )
                logging.debug("Pre-processed data file creation failed! <")
                logging.debug("")
            except FileNotFoundError:
                error(
                    "ERROR: Input/Ouput file path does not exists, check function arguments!"
                )
                logging.debug("Pre-processed data file creation failed! <")
                logging.debug("")
            except TypeError:
                error("ERROR: Given input/output file path type must be a string!")
                logging.debug("Pre-processed data file creation failed! <")
                logging.debug("")
            else:
                logging.debug("Pre-processed data file created! <")
                logging.debug("")
        except:
            error("ERROR: Given pre-processed data must be a list!")
            logging.debug("Pre-processed data file creation failed! <")
            logging.debug("")



import logging
import nltk

try:
    nltk.data.find("tokenizers/punkt")
except LookupError:
    nltk.download("punkt")

from nltk.tokenize import word_tokenize


def tokenizer(text, debug):
    """
    Method for tokenize text.

    :param text: The text to be preprocessed
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    text = word_tokenize(text)
    logging.debug("-- text tokenized!")

    return text


if __name__ == "__main__":
    tokenizer()



import logging


def accents(text, debug):
    """
    Method for delete accents.

    :param text: The text to be preprocessed
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    dictionary = {
        "a": ["á", "à", "â", "ä"],
        "e": ["é", "è", "ê", "ë"],
        "i": ["í", "ì", "î", "ï"],
        "o": ["ó", "ò", "ô", "ö"],
        "u": ["ú", "ù", "û", "ü"],
        "A": ["Á", "À", "Â", "Ä"],
        "E": ["É", "È", "Ê", "Ë"],
        "I": ["Í", "Ì", "Î", "Ï"],
        "O": ["Ó", "Ò", "Ô", "Ö"],
        "U": ["Ú", "Ù", "Û", "Ü"],
    }

    for no_accent, accent in dictionary.items():
        for type in accent:
            text = text.replace(type, no_accent)
    logging.debug("-- Accent cleanned!")

    return text


if __name__ == "__main__":
    accents()



from distutils.log import error
from pathlib import Path

import pandas as pd
import logging
import csv

path = Path(__file__).parent / "./_external/stopwords.csv"


class Stopwords:
    """Stopwords handler, add and delete stopwords."""

    def __init__(self, debug=False):
        """Stopwords handler, add and delete stopwords.

        Args:
            debug (bool, optional): Displays the code execution log by console. Defaults to False.
        """
        self.__debug = debug

    def append(self, words):
        """Method for adding a new word or words to the stopwords file.

        Args:
            words (str or list): words to add to stopwords file.
        """
        if self.__debug:
            logging.basicConfig(
                level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
            )

        try:
            if (type(words) != list) and (type(words) != str):
                raise TypeError
            try:
                if type(words) != str:
                    raise Exception
                with open(path, "a", newline="", encoding="utf-8") as stopwords_file:
                    fieldname = ["stopwords"]
                    writer = csv.DictWriter(stopwords_file, fieldnames=fieldname)
                    writer.writerow({"stopwords": words})
            except:
                with open(path, "a", newline="", encoding="utf-8") as stopwords_file:
                    fieldname = ["stopwords"]
                    writer = csv.DictWriter(stopwords_file, fieldnames=fieldname)
                    for word in words:
                        writer.writerow({"stopwords": word})
            finally:
                logging.debug("-- stopword/s added!")
        except TypeError:
            error(
                "¡ERROR: Given methods paramater type in object creation must be a string or list!"
            )
            logging.error("Stopword/s can not be added! <")
            logging.error("")

    def delete(self, words):
        """Method for delete a new word or words to the stopwords file.

        Args:
            words (str or list): words to delete to stopwords file.
        """
        if self.__debug:
            logging.basicConfig(
                level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
            )

        try:
            if (type(words) != list) and (type(words) != str):
                raise TypeError
            try:
                if type(words) != str:
                    raise Exception
                df = pd.read_csv(path)
                df = pd.read_csv(path)["stopwords"].tolist()
                df.remove(words)

                with open(path, "w", newline="", encoding="utf-8") as stopwords_file:
                    fieldnames = ["stopwords"]
                    writer = csv.DictWriter(stopwords_file, fieldnames=fieldnames)
                    writer.writeheader()
                    for stopword in df:
                        writer.writerow({"stopwords": stopword})
            except:
                df = pd.read_csv(path)
                df = pd.read_csv(path)["stopwords"].tolist()

                for word in words:
                    df.remove(word)

                with open(path, "w", newline="", encoding="utf-8") as stopwords_file:
                    fieldnames = ["stopwords"]
                    writer = csv.DictWriter(stopwords_file, fieldnames=fieldnames)
                    writer.writeheader()
                    for stopword in df:
                        writer.writerow({"stopwords": stopword})
            finally:
                logging.debug("-- stopword/s deleted!")
        except TypeError:
            error(
                "¡ERROR: Given methods paramater type in object creation must be a string or list!"
            )
            logging.error("Stopword/s can not be deleted! <")
            logging.error("")



from .__features.lev_distance import correction
import logging


def autocorrect(text, debug):
    """
    Method for auto-correct words in text.

    :param text: The text to be preprocessed.
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    text = text.split()
    texts = []

    for word in text:
        word_corrected = correction(word)
        texts.append(word_corrected)

    texts = " ".join(texts)
    logging.debug("-- Text corrected!")

    return texts


if __name__ == "__main__":
    autocorrect()



import logging
import re


def numbers_cleanner(text, debug):
    """
    Method for delete numbers.

    :param text: The text to be preprocessed
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    text = re.sub("\d", "", text)
    logging.debug("-- Numbers deleted!")
    return text


if __name__ == "__main__":
    numbers_cleanner()



import logging


def lowercasing(text, debug):
    """
    Method for lowercase text.

    :param text: The text to be preprocessed
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    text = "".join(word.lower() for word in text)
    logging.debug("-- The text is in lowercase!")
    return text


if __name__ == "__main__":
    lowercasing()



from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    LONG_DESC = fh.read()

    setup(
        long_description=LONG_DESC,
        long_description_content_type="text/markdown",
        name="preln",
        packages=find_packages(include=["Preln", "Preln.core", "Preln.core.__features"]),
        version="0.5.4",
        description="A preprocessing libray for text in spanish",
        author="Adrián H.S & Raúl M.R",
        author_email="adrihs.dev@gmail.com",
        license="MIT",
        install_requires=[
            "pandas",
            "nltk",
            "numpy",
            "openpyxl",
            "lxml",
            "sqlalchemy",
            "es_core_news_sm",
        ],
        setup_requires=["pytest-runner"],
        url="https://github.com/Adri-Hdez/Preln",
        tests_require=["pytest"],
        test_suite="tests",
        include_package_data=True,
    )



import logging
import string


def punctuation_es(text, debug):
    """
    Method for eliminate text punctuation.

    :param text: The text to be preprocessed
    :type: str

    :param debug: Apply debugging
    :type: bool
    """

    if debug:
        logging.basicConfig(
            level=logging.DEBUG, format="%(asctime)s | %(levelname)8s | %(message)s"
        )

    punctuation_words = string.punctuation + "¿¡·"
    text = "".join(word for word in text if word not in punctuation_words)
    logging.debug("-- Punctuation cleanned!")

    return text


if __name__ == "__main__":
    punctuation_es()
